
#ifndef _C12_ds573_
#define _C12_ds573_

#ifdef __cplusplus
extern "C" {
#endif

extern void F61_801(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit573(void);
extern long O803[];

#ifdef __cplusplus
}
#endif

#endif
